-l=79 # Max line width is 79 cols
-i=4 # Indent level is 4 cols
-ci=4 # Continuation indent is 4 cols

-se # Errors to STDERR
-vt=2 # Maximal vertical tightness
-cti=0 # No extra indentation for closing brackets
-pt=1 # Medium parenthesis tightness
-bt=1 # Medium brace tightness
-sbt=1 # Medium square bracket tightness
-bbt=1 # Medium block brace tightness
-nsfs # No space before semicolons
-nolq # Don't outdent long quoted strings
--break-at-old-comma-breakpoints
-wbb="% + - * / x != == >= <= =~ < > | & **= += *= &= <<= &&= -= /= |= >>= ||= .= %= ^= x="
# Break before all operators

# extras/overrides/deviations from PBP
--maximum-line-length=79 # be less generous
--warning-output # Show warnings
--maximum-consecutive-blank-lines=2 # default is 1
--nohanging-side-comments # troublesome for commented out code

-isbc # block comments may only be indented if they have some space characters before the #
-ci=2 # Continuation indent is 2 cols

# we use version control, so just rewrite the file
-b

## for the up-tight folk :)
#-pt=2 # High parenthesis tightness
#-bt=2 # High brace tightness
#-sbt=2 # High square bracket tightness
